"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const url = require("url");
const log = require("loglevel");
function appendProtocol(inputUrl) {
    const parsed = url.parse(inputUrl);
    if (!parsed.protocol) {
        const urlWithProtocol = `https://${inputUrl}`;
        log.warn(`URL "${inputUrl}" lacks a protocol.`, `Will try to parse it as HTTPS: "${urlWithProtocol}".`, `Please pass "http://${inputUrl}" if this is what you meant.`);
        return urlWithProtocol;
    }
    return inputUrl;
}
function normalizeUrl(urlToNormalize) {
    const urlWithProtocol = appendProtocol(urlToNormalize);
    let parsedUrl;
    try {
        parsedUrl = new url.URL(urlWithProtocol);
    }
    catch (err) {
        throw `Your url "${urlWithProtocol}" is invalid`;
    }
    const normalizedUrl = parsedUrl.toString();
    log.debug(`Normalized URL ${urlToNormalize} to:`, normalizedUrl);
    return normalizedUrl;
}
exports.normalizeUrl = normalizeUrl;
//# sourceMappingURL=normalizeUrl.js.map